[rkward-cvs] SF.net SVN: rkward:[3900] trunk/rkward/packages/rkwarddev/R/rk.plugin. skeleton.R
m-eik at users.sourceforge.net
m-eik at users.sourceforge.net
Fri Oct 7 15:22:53 UTC 2011
Revision: 3900
http://rkward.svn.sourceforge.net/rkward/?rev=3900&view=rev
Author: m-eik
Date: 2011-10-07 15:22:53 +0000 (Fri, 07 Oct 2011)
Log Message:
-----------
rkwarddev: adding support for author XML nodes to skeleton generation
Modified Paths:
--------------
trunk/rkward/packages/rkwarddev/R/rk.plugin.skeleton.R
Modified: trunk/rkward/packages/rkwarddev/R/rk.plugin.skeleton.R
===================================================================
--- trunk/rkward/packages/rkwarddev/R/rk.plugin.skeleton.R 2011-10-07 15:11:32 UTC (rev 3899)
+++ trunk/rkward/packages/rkwarddev/R/rk.plugin.skeleton.R 2011-10-07 15:22:53 UTC (rev 3900)
@@ -131,15 +131,25 @@
name <- clean.name(name)
if(!is.null(about)){
- # create an about.node, which probably has some default values
- about.node <- rk.XML.about(
- name=about[["name"]],
- author=about[["author"]],
- about=about[["about"]],
- dependencies=about[["dependencies"]],
- package=about[["package"]],
- pluginmap=about[["pluginmap"]]
- )
+ if(inherits(about, "XiMpLe.node")){
+ about.node.name <- about at name
+ # check if this is *really* a about section, otherwise quit and go dancing
+ if(!identical(about.node.name, "about")){
+ stop(simpleError("I don't know what this is, but 'about' is not an about section!"))
+ } else {
+ about.node <- about
+ }
+ } else {
+ # create an about.node, which probably has some default values
+ about.node <- rk.XML.about(
+ name=about[["name"]],
+ author=about[["author"]],
+ about=about[["about"]],
+ dependencies=about[["dependencies"]],
+ package=about[["package"]],
+ pluginmap=about[["pluginmap"]]
+ )
+ }
} else {
about.node <- NULL
# also stop creation of DESCRIPTION file
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
More information about the rkward-tracker
mailing list